@@ -1,11 +1,11 @@
 /*  File src/MHproposals_DynMLE.c in package tergm, part of the Statnet suite
- *  of packages for network analysis, http://statnet.org .
+ *  of packages for network analysis, https://statnet.org .
  *
  *  This software is distributed under the GPL-3 license.  It is free,
  *  open source, and has the attribution requirements (GPL Section 7) at
- *  http://statnet.org/attribution
+ *  https://statnet.org/attribution
  *
- *  Copyright 2008-2018 Statnet Commons
+ *  Copyright 2008-2019 Statnet Commons
  */
 #include "MHproposals_DynMLE.h"
 #include "edgelist.h"
@@ -18,7 +18,7 @@
    void MH_FormationMLE
    Propose ONLY edges not in the reference graph
 ***********************/
-void MH_FormationMLE (MHproposal *MHp, Network *nwp) 
+void MH_FormationMLE (MHProposal *MHp, Network *nwp) 
 {  
   static Vertex nnodes;
   static Edge nedges0;
@@ -26,7 +26,7 @@ void MH_FormationMLE (MHproposal *MHp, Network *nwp)
 
   if(MHp->ntoggles == 0) { /* Initialize */
     MHp->ntoggles=1;
-    nnodes = nwp[0].nnodes;
+    nnodes = nwp->nnodes;
     ndyads = DYADCOUNT(nnodes, 0, nwp[0].directed_flag);
     nedges0 = MHp->inputs[0];
     return;
@@ -49,14 +49,14 @@ void MH_FormationMLE (MHproposal *MHp, Network *nwp)
    void MH_FormationMLE
    Propose ONLY edges not in the reference graph
 ***********************/
-void MH_FormationMLETNT(MHproposal *MHp, Network *nwp) 
+void MH_FormationMLETNT(MHProposal *MHp, Network *nwp) 
 {  
   static Vertex nnodes;
   Vertex tail,head;
   static Edge nedges0;
   static Dyad ndyads;
   static double comp=0.5, odds;
-  static Network discord;
+  Network *discord;
 
   if(MHp->ntoggles == 0) { /* Initialize */
     MHp->ntoggles=1;
@@ -65,20 +65,20 @@ void MH_FormationMLETNT(MHproposal *MHp, Network *nwp)
     ndyads = DYADCOUNT(nnodes, nwp->bipartite, nwp[0].directed_flag);
 
     nedges0 = MHp->inputs[0];
-    MHp->discord = (Network**) calloc(2,sizeof(Network*)); // A space for the sentinel NULL pointer.
-    MHp->discord[0] = &discord;
-    discord = NetworkInitializeD(MHp->inputs+1, MHp->inputs+1+nedges0, nedges0, nnodes, nwp->directed_flag, nwp->bipartite, 0, 0, NULL);
+    MHp->discord = (Network**) Calloc(2,Network*); // A space for the sentinel NULL pointer.
+    MHp->discord[0] = discord = NetworkInitializeD(MHp->inputs+1, MHp->inputs+1+nedges0, nedges0, nnodes, nwp->directed_flag, nwp->bipartite, 0, 0, NULL);
    
     for(Edge i=0; i<nwp->nedges; i++){
       FindithEdge(&tail, &head, i+1, nwp);
-      ToggleEdge(tail,head, &discord);
+      ToggleEdge(tail,head, discord);
     }
     
     return;
   }
-  
 
-  Edge nedges = nwp->nedges, ndedges = discord.nedges;
+  discord = MHp->discord[0];
+
+  Edge nedges = nwp->nedges, ndedges = discord->nedges;
   Dyad nempty = ndyads-nedges;
 
   if(nempty==0 && ndedges==0){ /* Attempting formation on a complete graph. */
@@ -90,7 +90,7 @@ void MH_FormationMLETNT(MHproposal *MHp, Network *nwp)
   double logratio=0;
   BD_LOOP({
       if(ndedges != 0 && (nempty == 0 || unif_rand() < comp)) { /* Select a discordant dyad at random */
-	GetRandEdge(Mtail, Mhead, &discord);
+	GetRandEdge(Mtail, Mhead, discord);
 	
 	if(nempty==0){
 	  logratio = log(ndedges*(1-comp));
@@ -123,12 +123,12 @@ void MH_FormationMLETNT(MHproposal *MHp, Network *nwp)
    void MH_DissolutionMLE
    Propose ONLY edges in the reference graph
 ***********************/
-void MH_DissolutionMLETNT(MHproposal *MHp, Network *nwp) 
+void MH_DissolutionMLETNT(MHProposal *MHp, Network *nwp) 
 {  
   static Vertex nnodes;
   Vertex tail,head;
   static double comp=0.5, odds;
-  static Network discord;
+  Network *discord;
   static Edge nedges0;
 
   if(MHp->ntoggles == 0) { /* Initialize */
@@ -137,20 +137,20 @@ void MH_DissolutionMLETNT(MHproposal *MHp, Network *nwp)
     odds = comp/(1.0-comp);
 
     nedges0 = MHp->inputs[0];
-    MHp->discord = (Network**) calloc(2,sizeof(Network*)); // A space for the sentinel NULL pointer.
-    MHp->discord[0] = &discord;
-    discord = NetworkInitializeD(MHp->inputs+1, MHp->inputs+1+nedges0, nedges0, nnodes, nwp->directed_flag, nwp->bipartite, 0, 0, NULL);
+    MHp->discord = (Network**) Calloc(2,Network*); // A space for the sentinel NULL pointer.
+    MHp->discord[0] = discord = NetworkInitializeD(MHp->inputs+1, MHp->inputs+1+nedges0, nedges0, nnodes, nwp->directed_flag, nwp->bipartite, 0, 0, NULL);
    
     for(Edge i=0; i<nwp->nedges; i++){
       FindithEdge(&tail, &head, i+1, nwp);
-      ToggleEdge(tail,head, &discord);
+      ToggleEdge(tail,head, discord);
     }
     
     return;
   }
-  
 
-  Edge nedges = nwp->nedges, ndedges = discord.nedges;
+  discord = MHp->discord[0];
+
+  Edge nedges = nwp->nedges, ndedges = discord->nedges;
 
   if(nedges==0 && ndedges==0){ /* Attempting dissolution on an empty graph. */
     Mtail[0]=MH_FAILED;
@@ -161,7 +161,7 @@ void MH_DissolutionMLETNT(MHproposal *MHp, Network *nwp)
   double logratio=0;
   BD_LOOP({
       if(ndedges != 0 && (nedges == 0 || unif_rand() < comp)) { /* Select a discordant dyad at random */
-	GetRandEdge(Mtail, Mhead, &discord);
+	GetRandEdge(Mtail, Mhead, discord);
 	
 	if(nedges==0){
 	  logratio = log(ndedges*(1-comp));
